@@ -1,10 +1,4 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/11/26 3:56 下午
-# Copyright (C) 2021 The lesscode Team
-import asyncio
-from asyncio import events
 
 from tornado.options import options
 
