@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2022/2/17 2:45 下午
-# Copyright (C) 2022 The lesscode Team
+import importlib
+
 from lesscode.db.base_connection_pool import BaseConnectionPool
-from elasticsearch import AsyncElasticsearch
-from elasticsearch import Elasticsearch
+
+elasticsearch = None
+try:
+    elasticsearch = importlib.import_module("elasticsearch")
+except ImportError as e:
+    raise Exception(f"elasticsearch is not exist,run:pip install elasticsearch==7.15.2")
 
 
 class ElasticsearchPool(BaseConnectionPool):
@@ -23,7 +25,7 @@ class ElasticsearchPool(BaseConnectionPool):
         if info.async_enable:
             host_str = info.host.split(",")
             hosts = [f"http://{info.user}:{info.password}@{host}:{info.port}" for host in host_str]
-            pool = AsyncElasticsearch(hosts=hosts)
+            pool = elasticsearch.AsyncElasticsearch(hosts=hosts)
             return pool
         else:
             raise NotImplementedError
@@ -32,5 +34,5 @@ class ElasticsearchPool(BaseConnectionPool):
         info = self.conn_info
         host_str = info.host.split(",")
         hosts = [f"http://{info.user}:{info.password}@{host}:{info.port}" for host in host_str]
-        pool = Elasticsearch(hosts)
+        pool = elasticsearch.Elasticsearch(hosts)
         return pool
