@@ -113,6 +113,8 @@ def query_set_to_dict(obj):
         return obj_dict
     elif hasattr(obj, "keys"):
         return {key: getattr(obj, key) for key in obj.keys()}
+    elif hasattr(obj, "_asdict"):
+        return obj._asdict()
     else:
         return dict(obj)
 
