@@ -28,6 +28,14 @@ class SqlAlchemyPool(BaseConnectionPool):
             url = 'postgresql+psycopg2://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
                 self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
                 self.conn_info.db_name)
+        elif db_type == "tidb":
+            url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
+                self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
+                self.conn_info.db_name)
+        elif db_type == "ocean_base":
+            url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
+                self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
+                self.conn_info.db_name)
         else:
             raise Exception("UNSUPPORTED DB TYPE")
         engine = sqlalchemy.create_engine(url, echo=self.conn_info.params.get("echo",
