@@ -1,18 +1,20 @@
 import importlib
-import json
 import random
 
-import aiohttp
 import tornado.options
-import requests
-from lesscode.web.status_code import StatusCode
 
 from lesscode.web.business_exception import BusinessException
+from lesscode.web.status_code import StatusCode
 
 
 async def post(path, data=None,
                base_url=tornado.options.options.data_server,
                result_type="json", pack=False, **kwargs):
+    try:
+        aiohttp = importlib.import_module("aiohttp")
+    except ImportError as e:
+        raise Exception(f"aiohttp is not exist,run:pip install aiohttp==3.8.3")
+
     project_name = tornado.options.options.project_name.encode("utf-8")
     flag = kwargs.pop("flag", True)
     if flag:
@@ -66,6 +68,10 @@ async def post(path, data=None,
 
 async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False,
               **kwargs):
+    try:
+        aiohttp = importlib.import_module("aiohttp")
+    except ImportError as e:
+        raise Exception(f"aiohttp is not exist,run:pip install aiohttp==3.8.3")
     project_name = tornado.options.options.project_name.encode("utf-8")
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
@@ -91,19 +97,47 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
             return result
 
 
-def sync_get(path, params=None, base_url=None, result_type="json", pack=False, **kwargs):
+def sync_common_request(method, path, params=None, data=None, json=None, base_url=None, result_type="json",
+                        pack=False, connect_config=None, **kwargs):
+    try:
+        requests = importlib.import_module("requests")
+        requests_adapters = importlib.import_module("requests.adapters")
+    except ImportError as e:
+        raise Exception(f"requests is not exist,run:pip install requests==2.27.1")
     project_name = tornado.options.options.project_name.encode("utf-8")
     if not base_url:
         base_url = tornado.options.options.data_server
-    if not kwargs.get("headers") and project_name:
+    if not kwargs.get("headers"):
         kwargs.update({"headers": {
             "Project-Name": project_name
         }})
-    elif project_name:
+    else:
         kwargs["headers"].update({"Project-Name": project_name})
+    if not connect_config:
+        connect_config = {
+            "pool_connections": 10,
+            "pool_maxsize": 10,
+            "max_retries": 0,
+            "pool_block": False
+        }
     s = requests.session()
+    if connect_config and isinstance(connect_config, dict):
+        adapter = requests_adapters.HTTPAdapter(**connect_config)
+        s.mount(prefix="http", adapter=adapter)
+        s.mount(prefix="https", adapter=adapter)
     try:
-        res = s.get(base_url + path, params=params, **kwargs)
+        if method == "GET":
+            res = s.get(base_url + path, params=params, data=data, json=json, **kwargs)
+        elif method == "POST":
+            res = s.post(base_url + path, params=params, data=data, json=json, **kwargs)
+        elif method == "PUT":
+            res = s.put(base_url + path, params=params, data=data, json=json, **kwargs)
+        elif method == "PATCH":
+            res = s.patch(base_url + path, params=params, data=data, json=json, **kwargs)
+        elif method == "DELETE":
+            res = s.delete(base_url + path, params=params, data=data, json=json, **kwargs)
+        else:
+            raise Exception(f"method={method} is not allowed")
     except Exception as e:
         raise e
     finally:
@@ -123,48 +157,54 @@ def sync_get(path, params=None, base_url=None, result_type="json", pack=False, *
     return res
 
 
+def sync_get(path, params=None, base_url=None, result_type="json", pack=False, connect_config=None, **kwargs):
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    res = sync_common_request(method="GET", path=path, params=params, base_url=base_url,
+                              result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
+    return res
+
+
 def sync_post(path, data=None,
               base_url=None,
-              result_type="json", pack=False, **kwargs):
-    project_name = tornado.options.options.project_name.encode("utf-8")
-    if not base_url:
-        base_url = tornado.options.options.data_server
+              result_type="json", pack=False, connect_config=None, **kwargs):
     flag = kwargs.pop("flag", True)
-    s = requests.session()
-    try:
-        if flag:
-            if not kwargs.get("headers"):
-                kwargs.update({"headers": {
-                    "Content-Type": "application/json",
-                    "Project-Name": project_name
-                }})
-            else:
-                kwargs["headers"].update({"Project-Name": project_name})
-            res = s.post(base_url + path, json=data, **kwargs)
-        else:
-            if not kwargs.get("headers"):
-                kwargs.update({"headers": {
-                    "Project-Name": project_name
-                }})
-            else:
-                kwargs["headers"].update({"Project-Name": project_name})
-            res = s.post(base_url + path, data=data, **kwargs)
-    except Exception as e:
-        raise e
-    finally:
-        s.close()
-    if result_type == "json":
-        res = res.json()
-        if not pack:
-            if res.get("status") == "00000":
-                res = res.get("data")
-            else:
-                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
-                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
-    elif result_type == "text":
-        res = res.text
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    if flag:
+        res = sync_common_request(method="POST", path=path, json=data, base_url=base_url,
+                                  result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
+        return res
     else:
-        res = res.content
+        res = sync_common_request(method="POST", path=path, data=data, base_url=base_url,
+                                  result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
+        return res
+
+
+def sync_patch(path, params=None, data=None, json=None, base_url=None,
+               result_type="json", pack=False, connect_config=None, **kwargs):
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    res = sync_common_request(method="PATCH", path=path, params=params, data=data, json=json, base_url=base_url,
+                              result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
+    return res
+
+
+def sync_put(path, params=None, data=None, json=None, base_url=None,
+             result_type="json", pack=False, connect_config=None, **kwargs):
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    res = sync_common_request(method="PATCH", path=path, params=params, data=data, json=json, base_url=base_url,
+                              result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
+    return res
+
+
+def sync_delete(path, params=None, data=None, json=None, base_url=None,
+                result_type="json", pack=False, connect_config=None, **kwargs):
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    res = sync_common_request(method="DELETE", path=path, params=params, data=data, json=json, base_url=base_url,
+                              result_type=result_type, pack=pack, connect_config=connect_config, **kwargs)
     return res
 
 
@@ -213,7 +253,7 @@ def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE",
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
     if tornado.options.options.running_env != "local":
-
+        import json
         res = eureka_request(path=path, return_type=return_type, method="POST", data=json.dumps(data),
                              app_name=app_name,
                              pack=pack, **kwargs)
@@ -271,12 +311,15 @@ def nacos_post(path, data=None, service_name=None, namespace="public", clusters=
 
 
 def common_get(path, params=None, service_name=None, namespace="public", clusters=None, group_name=None,
-               pack=False, return_type="json", **kwargs):
+               pack=False, return_type="json", connect_config=None, **kwargs):
     base_url = tornado.options.options.data_server
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
     if tornado.options.options.request_type == "request":
-        res = sync_get(path=path, params=params, base_url=base_url, result_type=return_type, pack=pack, **kwargs)
+        res = sync_get(path=path, params=params, base_url=base_url, result_type=return_type, pack=pack,
+                       connect_config=connect_config, **kwargs)
         return res
     elif tornado.options.options.request_type == "eureka":
         res = eureka_get(path=path, data=params, return_type=return_type, app_name=service_name, pack=pack, **kwargs)
@@ -290,12 +333,15 @@ def common_get(path, params=None, service_name=None, namespace="public", cluster
 
 
 def common_post(path, data=None, service_name=None, namespace="public", clusters=None, group_name=None,
-                pack=False, return_type="json", **kwargs):
+                pack=False, return_type="json", connect_config=None, **kwargs):
     base_url = tornado.options.options.data_server
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
     if kwargs.get("base_url") is not None:
         base_url = kwargs.pop("base_url")
     if tornado.options.options.request_type == "request":
-        res = sync_post(path=path, data=data, base_url=base_url, result_type=return_type, pack=pack, **kwargs)
+        res = sync_post(path=path, data=data, base_url=base_url, result_type=return_type, pack=pack,
+                        connect_config=connect_config, **kwargs)
         return res
     elif tornado.options.options.request_type == "eureka":
         res = eureka_post(path=path, data=data, return_type=return_type, app_name=service_name, pack=pack, **kwargs)
@@ -307,3 +353,48 @@ def common_post(path, data=None, service_name=None, namespace="public", clusters
         return res
     else:
         raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
+
+
+def common_put(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None, **kwargs):
+    base_url = tornado.options.options.data_server
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    if tornado.options.options.request_type == "request":
+        res = sync_put(path=path, params=params, data=data, json=json,
+                       base_url=base_url, result_type=return_type, pack=pack, connect_config=connect_config, **kwargs)
+        return res
+    else:
+        raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
+
+
+def common_patch(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None,
+                 **kwargs):
+    base_url = tornado.options.options.data_server
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    if tornado.options.options.request_type == "request":
+        res = sync_patch(path=path, params=params, data=data, json=json,
+                         base_url=base_url, result_type=return_type, pack=pack, connect_config=connect_config, **kwargs)
+        return res
+    else:
+        raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
+
+
+def common_delete(path, params=None, data=None, json=None, pack=False, return_type="json", connect_config=None,
+                  **kwargs):
+    base_url = tornado.options.options.data_server
+    if connect_config is None:
+        connect_config = tornado.options.options.connect_config
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
+    if tornado.options.options.request_type == "request":
+        res = sync_delete(path=path, params=params, data=data, json=json,
+                          base_url=base_url, result_type=return_type, pack=pack, connect_config=connect_config,
+                          **kwargs)
+        return res
+    else:
+        raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
