@@ -94,7 +94,7 @@ class BaseHandler(RequestHandler):
             self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
 
     @contextmanager
-    def make_session(self, pool, **kwargs):
+    def make_sqlalchemy_session(self, pool, **kwargs):
         pool, _ = options.database[pool]
         try:
             sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
