@@ -1,21 +1,16 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/11/4 11:00 上午
-# Copyright (C) 2021 The lesscode Team
+
 import logging
 import threading
 
 import tornado.options
-from requests import post, get
+from tornado.options import define
 from tornado.web import RequestHandler
 
-from lesscode.db.redis.redis_helper import RedisHelper
 from lesscode.utils.doc.interface_doc_handler import parser_swagger
 from lesscode.utils.upms_util import upms_register
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
-from tornado.options import define
 
 define("route_prefix", default="", type=str, help="路由前缀")
 tornado.options.options.route_prefix = ""
