@@ -1,10 +1,4 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/11/9 4:47 下午
-# Copyright (C) 2021 The lesscode Team
-
-from typing import Tuple
 
 
 class StatusCode:
