@@ -1,24 +1,22 @@
 # -*- coding: utf-8 -*-
 import asyncio
 import importlib
-import os
-import sys
 import logging
+import os
+import platform
+import sys
 import traceback
-
-import tornado.web
-import tornado.ioloop
-import tornado.httpserver
-from tornado.log import LogFormatter as TornadoLogFormatter  # 避免命名歧义，设置了别名
-from tornado.options import options, define
 from typing import Optional
 
-from tornado_sqlalchemy import SQLAlchemy
+import tornado.httpserver
+import tornado.ioloop
+import tornado.web
+from tornado.log import LogFormatter as TornadoLogFormatter  # 避免命名歧义，设置了别名
+from tornado.options import options, define
 
 from lesscode.db.init_connection_pool import InitConnectionPool
 from lesscode.extend_handlers.not_found_handler import NotFoundHandler
 from lesscode.web.router_mapping import RouterMapping
-import platform
 
 define("application_name", default=f"{os.path.split(os.path.abspath(os.path.dirname(sys.argv[0])))[-1]}", type=str,
        help="应用名称")
@@ -41,8 +39,9 @@ define("rms_register_enable", default=False, type=bool, help="是否启动资源
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 define("running_env", default="local", type=str, help="运行环境")
 define("request_type", default="request", type=str, help="请求类型")
-define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
+define("db", default=None, type=object, help="SqlAlchemy")
 define("ks3_connect_config", default={}, type=dict, help="金山对象存储连接配置")
+define("connect_config", default={}, type=dict, help="requests包的连接配置")
 define("scheduler", default=None, type=object, help="Tornado任务调度")
 define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
 define("nacos_config", default={}, type=dict, help="nacos配置")
